==> haskell-casa-types-0.0.2-78-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-casa-types.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 casa-types
version:              0.0.2
visibility:           public
id:                   casa-types-0.0.2-6Cexva6xxFxAUj75FUhThg
key:                  casa-types-0.0.2-6Cexva6xxFxAUj75FUhThg
license:              BSD-3-Clause
copyright:            2018-2019 FP Complete
maintainer:           chrisdone@fpcomplete.com
author:               Chris Done
synopsis:             Types for Casa
description:          Types for Casa <https://casa.fpcomplete.com/>
category:             Development
abi:                  cd029985e4c8789f8f1552e11944229a
exposed:              True
exposed-modules:      Casa.Types
hidden-modules:       Paths_casa_types
import-dirs:          /usr/lib/ghc-8.10.4/site-local/casa-types-0.0.2
library-dirs:         /usr/lib/ghc-8.10.4/site-local/casa-types-0.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/casa-types-0.0.2
hs-libraries:         HScasa-types-0.0.2-6Cexva6xxFxAUj75FUhThg
depends:
    aeson-1.5.6.0-1F4wJcYByqDF2zyvzlYTcu
    attoparsec-0.14.1-LkeByB68Bw23cZHiDQM5Wy base-4.14.1.0
    base16-bytestring-1.0.1.0-45qdpKhBXxm3SdtVglCVLq
    bytestring-0.10.12.0 hashable-1.3.1.0-1TzQw0rlraYH9EvMt0jxBh
    path-pieces-0.2.1-8q2eB6sQVysEcd9HpZsL9B
    persistent-2.11.0.4-8pqIPkYXTcfCazS7we3MOr text-1.2.4.1

haddock-interfaces:   /usr/share/doc/haskell-casa-types/html/casa-types.haddock
haddock-html:         /usr/share/doc/haskell-casa-types/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-casa-types-0.0.2-81-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-casa-types.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 casa-types
version:              0.0.2
visibility:           public
id:                   casa-types-0.0.2-ts7cncyd6S4EDZW6ukr47
key:                  casa-types-0.0.2-ts7cncyd6S4EDZW6ukr47
license:              BSD-3-Clause
copyright:            2018-2019 FP Complete
maintainer:           chrisdone@fpcomplete.com
author:               Chris Done
synopsis:             Types for Casa
description:          Types for Casa <https://casa.fpcomplete.com/>
category:             Development
abi:                  cb29c140ab941d28f5cfc51f807dc4cf
exposed:              True
exposed-modules:      Casa.Types
hidden-modules:       Paths_casa_types
import-dirs:          /usr/lib/ghc-8.10.4/site-local/casa-types-0.0.2
library-dirs:         /usr/lib/ghc-8.10.4/site-local/casa-types-0.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/casa-types-0.0.2
hs-libraries:         HScasa-types-0.0.2-ts7cncyd6S4EDZW6ukr47
depends:
    aeson-1.5.6.0-I7BbKEwOl3UEL7J6p5LGbn
    attoparsec-0.14.1-JkI3X5d36Qk8oyVdsBgtBB base-4.14.1.0
    base16-bytestring-1.0.1.0-JclBqFMO1eX94FYTHG5WbF
    bytestring-0.10.12.0 hashable-1.3.1.0-1TzQw0rlraYH9EvMt0jxBh
    path-pieces-0.2.1-8q2eB6sQVysEcd9HpZsL9B
    persistent-2.11.0.4-CkwB1M0mGu3KED0Uhj8eTl text-1.2.4.1

haddock-interfaces:   /usr/share/doc/haskell-casa-types/html/casa-types.haddock
haddock-html:         /usr/share/doc/haskell-casa-types/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
